yt.visualization.plot_window.ProjectionPlot.set_zlim — The yt Project 3.2-dev documentation

# yt.visualization.plot_window.ProjectionPlot.set_zlim

`ProjectionPlot.` `set_zlim`(*args, **kwargs)

  set the scale of the colormap

  Parameters: | field : string the field to set a colormap scale if field == ‘all’, applies to all plots. zmin : float the new minimum of the colormap scale. If ‘min’, will set to the minimum value in the current view. zmax : float the new maximum of the colormap scale. If ‘max’, will set to the maximum value in the current view.
  Other Parameters:
  | dynamic_range : float (default: None) The dynamic range of the image. If zmin == None, will set zmin = zmax / dynamic_range If zmax == None, will set zmax = zmin * dynamic_range When dynamic_range is specified, defaults to setting zmin = zmax / dynamic_range.